package org.firstinspires.ftc.teamcode;

import com.acmerobotics.roadrunner.SleepAction;
import com.qualcomm.robotcore.eventloop.opmode.Autonomous;
import com.qualcomm.robotcore.eventloop.opmode.OpMode;
import com.qualcomm.robotcore.util.ElapsedTime;

import org.firstinspires.ftc.teamcode.pedroPathing.follower.Follower;
import org.firstinspires.ftc.teamcode.subsystems.ArmSubsystem;
import org.firstinspires.ftc.teamcode.subsystems.ClawSubsystem;
import org.firstinspires.ftc.teamcode.subsystems.DualMotorSliderSubsystem;
import org.firstinspires.ftc.teamcode.subsystems.HangMotorSubsystem;
import org.firstinspires.ftc.teamcode.subsystems.WristSubsystem;

@Autonomous(name = "Specimen Auto", group = "Development")

public class SpecimenAuto extends OpMode {
    private Follower follower;
    private int state;
    private ElapsedTime runtime;

    private DualMotorSliderSubsystem lift;
    private ClawSubsystem claw;
    private WristSubsystem wrist;
    private ArmSubsystem arm;
    private HangMotorSubsystem hang;



    @Override
     public void init(){
         lift = new DualMotorSliderSubsystem(hardwareMap);
         claw = new ClawSubsystem(hardwareMap);
         arm = new ArmSubsystem(hardwareMap);
         wrist = new WristSubsystem(hardwareMap);
         hang = new HangMotorSubsystem(hardwareMap);
         follower = new Follower(hardwareMap);
         runtime = new ElapsedTime();

         state = 0;
         lift.init();
         claw.init();
         wrist.InitAuto();
         arm.initAuto();

        follower.setMaxPower(.45);


     }

    @Override
    public void loop() {
        telemetry.addData("state", state);
         switch(state) {
             case 0:
                 wrist.toSpecimenPrep();
                 arm.toSpecimenPrep();
                 state = 1;
                 new SleepAction(5);
                 break;
             case 1:
                state = 2;
                 break;
             case 2:
                 lift.toSpecimanHangHeight();
                 new SleepAction(5);
                 state = 3;
                 break;
             case 3:
                 wrist.toSpecimenHang();
                 new SleepAction(5);
                 state = 4;
                 break;
             case 4:
                 lift.toSpecimanReleaseHeight();
                 new SleepAction(5);
                 state = 5;
                 break;
             case 5:
                 //specimen drop
                 break;
             case 6:
                 //path 4
                 break;
             case 7:
                 //specimen pick up
                 break;
             case 8:
                 //path 5
                 break;
             case 9:
                 //specimen drop
                 break;
             case 10:
                 //path 6
                 break;
             case 11:
                 //specimen pickup
                 break;
             case 12:
                 //path 7
                 break;
             case 13:
                 //specimen drop
                 break;
         }
         new SleepAction(5);
    }

}
