package org.firstinspires.ftc.teamcode.cometbots;

import static org.firstinspires.ftc.teamcode.PedroConstants.MAX_POWER;

import com.qualcomm.robotcore.hardware.Gamepad;
import com.qualcomm.robotcore.hardware.HardwareMap;

import org.firstinspires.ftc.teamcode.pedroPathing.follower.Follower;
import org.firstinspires.ftc.teamcode.subsystems.ArmSubsystem;
import org.firstinspires.ftc.teamcode.subsystems.ClawSubsystem;
import org.firstinspires.ftc.teamcode.subsystems.DualMotorSliderSubsystem;
import org.firstinspires.ftc.teamcode.subsystems.HangMotorSubsystem;
import org.firstinspires.ftc.teamcode.subsystems.WristSubsystem;

public class CometBotTeleOpDevelopment {

    /*
    Subsystems
     */
    private DualMotorSliderSubsystem dualSlides;
    private ClawSubsystem claw;
    private WristSubsystem wrist;
    private ArmSubsystem arm;
    private HangMotorSubsystem skyhook;
    /*
    Controllers
     */
    public Gamepad gamepad1;
    public Gamepad gamepad2;
    public Gamepad currentGamepad1;
    public Gamepad currentGamepad2;
    public Gamepad previousGamepad1;
    public Gamepad previousGamepad2;

    public boolean wristPickup;
    public boolean armParked;
    public boolean goClaw;
    private Follower follower;

    public CometBotTeleOpDevelopment(HardwareMap hardwareMap, Gamepad gamepad1, Gamepad gamepad2) {
        dualSlides = new DualMotorSliderSubsystem(hardwareMap);
        claw = new ClawSubsystem(hardwareMap);
        arm = new ArmSubsystem(hardwareMap);
        wrist = new WristSubsystem(hardwareMap);
        skyhook = new HangMotorSubsystem(hardwareMap);

        this.gamepad1 = gamepad1;
        this.gamepad2 = gamepad2;
        currentGamepad1 = new Gamepad();
        currentGamepad2 = new Gamepad();
        previousGamepad1 = new Gamepad();
        previousGamepad2 = new Gamepad();
        follower = new Follower(hardwareMap);

    }

    public void init() {
        dualSlides.init();
        claw.init();
        wrist.initTeleOp();
        arm.initTeleOp();
        skyhook.init();
        follower.setMaxPower(MAX_POWER);
        follower.startTeleopDrive();
        wristPickup = false;
        armParked = true;
        goClaw = false;
    }

    public void update() {
        previousGamepad1.copy(currentGamepad1);
        currentGamepad1.copy(gamepad1);
        previousGamepad2.copy(currentGamepad2);
        currentGamepad2.copy(gamepad2);

        //slides
        dualSlides.update();
        dualSlidesToLowBucketPosition();
        dualSlidesToHighBucketPosition();
        dualSlidesToFloorPosition();
        //arm
        armToParkPosition();
        armAndWristToFloor();
        armToBucketPosition();
        //claw
        openClaw();
        openThumb();
        //hang
        hang();
        follower.setTeleOpMovementVectors(-gamepad1.left_stick_y, -gamepad1.left_stick_x, -gamepad1.right_stick_x);
        follower.update();
    }
    private void openClaw() {
        if (currentGamepad2.right_bumper && !previousGamepad2.right_bumper) {
            claw.switchState();
        }
    }

    private void openThumb() {
        if (currentGamepad2.left_bumper && !previousGamepad2.left_bumper) {
            claw.switchTState();

        }
    }

    private void armAndWristToFloor() {
        if (currentGamepad2.a && !previousGamepad2.a && wristPickup) {
            if (wrist.getState() != WristSubsystem.WristState.FLOOR) {
                wrist.toFloorPositionTeleop();
            } else if (wristPickup) {
                claw.openClaw();
                wrist.toPickupPosition();
            }
        }
        if (currentGamepad2.a && !previousGamepad2.a) {
            arm.toFloorPositionTeleOp();

            wristPickup = true;
            armParked = false;
        }
    }

    private void armToBucketPosition() {
        if (currentGamepad2.dpad_up && !previousGamepad2.dpad_up) {
            armParked = true;
            arm.toBucketPosition();
            wrist.toBucketPosition();
            wristPickup = false;

        }
    }

    private void armToParkPosition() {
        if (currentGamepad2.x && !previousGamepad2.x) {
            armParked = true;
            arm.toParkPosition();
            wrist.toFloorPositionTeleop();
            wristPickup = false;

        }
    }

    private void dualSlidesToHighBucketPosition() {
        if (currentGamepad2.y && !previousGamepad2.y && armParked) {
            dualSlides.toHighBucketPosition();
        }
    }

    private void dualSlidesToFloorPosition() {
        if (currentGamepad2.dpad_down && !previousGamepad2.dpad_down && armParked) {
            dualSlides.toFloorPosition();
        }
    }

    private void dualSlidesToLowBucketPosition() {
        if (currentGamepad2.b && !previousGamepad2.b && armParked) {
            dualSlides.toLowBucketPosition();
        }
    }
    private void hang(){
        if (gamepad1.a) {
            claw.grabBlueberry();
            arm.setPosition(0.15);
            arm.grabBlueberrySkyhook();

            //claw Open small amount
            wrist.grabBlueberrySkyhook();
            //wrist grab in strange way
        }
        if(gamepad1.b) {
            //confirm grab
            claw.closeClaw();

        }

        if (gamepad1.x && claw.getState() == ClawSubsystem.ClawState.CLOSED) {
            //now slap on bar, first wrist, then arm, then claw then driver must drive away
            dualSlides.toFixedPosition(500);
            dualSlides.update();
        }

        if (gamepad1.y) {
            arm.hangBlueberrySkyhook();
            wrist.hangBlueberrySkyhook();
            try {
                Thread.sleep(500);
            } catch (InterruptedException e) {
                throw new RuntimeException(e);
            }
            goClaw = true;
            dualSlides.toFixedPosition(2200);
            dualSlides.update();
        }
        if (gamepad1.right_bumper) {
            claw.openClaw();
            if(goClaw == true) {
                try {
                    Thread.sleep(500);
                } catch (InterruptedException e) {
                    throw new RuntimeException(e);
                }
                dualSlides.toFloorPosition();
                dualSlides.update();
                arm.toParkPosition();
                wrist.toPickupPosition();
            }
        }
        skyhook.setPowerForward(-gamepad2.right_stick_y);




    }

}
